Requests cleanup of an fmalloc runtime. If vectors allocated from the runtime are still reachable, the native mapping is kept alive until those vectors are garbage-collected.
Arguments
- runtime
Optional runtime handle returned by
open_fmalloc(). If not supplied, the current default runtime is cleaned up.
Examples
if (FALSE) { # \dontrun{
init_fmalloc("data.bin")
v <- create_fmalloc_vector("integer", 100)
rm(v)
gc()
cleanup_fmalloc()
} # }